==> snaxdart_models-1.0.1.tar.gz: lib/src/v1/transactions.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:equatable/equatable.dart';
import 'package:snaxdart_errors/snaxdart_errors.dart';
import 'package:snaxdart_models/v1.dart';

part 'transactions.g.dart';

@JsonSerializable()
class WalletTransactions extends Equatable {
  @JsonKey(name: 'data')
  final List<WalletTransaction> data;

  @JsonKey(name: 'has_more')
  final bool hasMore;

  @JsonKey(name: 'loading', ignore: true)
  final bool loading;

  @JsonKey(name: 'error', ignore: true)
  final SnaxError error;

  WalletTransactions({this.data, loading, error, this.hasMore})
      : this.loading = loading ?? false,
        this.error = error,
        super();

  WalletTransactions.initialState()
      : data = [],
        loading = false,
        hasMore = false,
        error = null;

  WalletTransactions copyWith({
    List<WalletTransaction> data,
    bool loading,
    bool hasMore,
    SnaxError error,
  }) {
    return WalletTransactions(
      data: data ?? this.data,
      loading: loading ?? this.loading,
      hasMore: hasMore ?? this.hasMore,
      error: error ?? this.error,
    );
  }

  WalletTransactions resetError() {
    return WalletTransactions(
      error: null,
      loading: this.loading,
      data: this.data,
      hasMore: this.hasMore,
    );
  }

  factory WalletTransactions.fromJson(Map<String, dynamic> json) =>
      _$WalletTransactionsFromJson(json);

  Map<String, dynamic> toJson() => _$WalletTransactionsToJson(this);

  @override
  String toString() => this.toJson().toString();
}

==> snaxdart_models-1.1.31.tar.gz: lib/src/v1/transactions.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:equatable/equatable.dart';
import 'package:snaxdart_errors/snaxdart_errors.dart';
import 'package:snaxdart_models/v1.dart';

part 'transactions.g.dart';

@JsonSerializable()
class WalletTransactions extends Equatable {
  @JsonKey(name: 'data')
  final List<WalletTransaction> data;

  @JsonKey(name: 'incomplete')
  final List<IncompleteWalletTransaction> incomplete;

  @JsonKey(name: 'has_more')
  final bool hasMore;

  @JsonKey(name: 'loading', ignore: true)
  final bool loading;

  @JsonKey(name: 'error', ignore: true)
  final SnaxError error;

  WalletTransactions({data, incomplete, loading, error, this.hasMore})
      : this.data = data ?? [],
        this.incomplete = incomplete ?? [],
        this.loading = loading ?? false,
        this.error = error ?? null,
        super();

  WalletTransactions.initialState()
      : data = [],
        incomplete = [],
        loading = false,
        hasMore = false,
        error = null;

  WalletTransactions copyWith({
    List<WalletTransaction> data,
    List<IncompleteWalletTransaction> incomplete,
    bool loading,
    bool hasMore,
    SnaxError error,
  }) {
    return WalletTransactions(
      data: data ?? this.data ?? [],
      incomplete: incomplete ?? this.incomplete ?? [],
      loading: loading ?? this.loading,
      hasMore: hasMore ?? this.hasMore,
      error: error ?? this.error,
    );
  }

  WalletTransactions resetError() {
    return WalletTransactions(
      error: null,
      loading: this.loading,
      data: this.data,
      incomplete: this.incomplete,
      hasMore: this.hasMore,
    );
  }

  factory WalletTransactions.fromJson(Map<String, dynamic> json) =>
      _$WalletTransactionsFromJson(json);

  Map<String, dynamic> toJson() => _$WalletTransactionsToJson(this);

  @override
  String toString() => this.toJson().toString();
}
